@@ -1,3 +1,6 @@
+from gql.dsl import DSLMetaField
+
+
 class MeFields:
     @staticmethod
     def fields(ds):
@@ -16,4 +19,5 @@ class MeFields:
             ds.User.termsAgreed,
             ds.User.rawID,
             ds.User.permissions.select(ds.Permission.code),
+            DSLMetaField("__typename"),
         )
